Downloads — PyTables 3.1.1 documentation

### Navigation

- index
- modules
- modules
- next
- previous
- PyTables 3.1.1 documentation »

# Downloads

## Stable Versions

The stable versions of PyTables can be downloaded from the file download area on SourceForge.net. The full distribution contains a copy of this documentation in HTML. The documentation in both HTML and PDF formats can also be downloaded separately from the same URL.

A pure source version of the package (mainly intended for developers and packagers) is available on the tags page on GitHub. It contains all files under SCM but not the (generated) files, HTML doc and cythonized C extensions, so it is smaller that the standard package (about 3.5MB).

Windows binaries can be obtained from many different distributions, like Python(x,y), ActiveState, or Enthought. In addition, Christoph Gohlke normally does an excellent job by providing binaries for many interesting software on his website.

You may be interested to easy_install the latest released stable version:

    $ easy_install tables

Or, you may prefer to install the stable version in Git repository instead using pip. For example, for the stable 2.3 series, you can do:

    $ pip install --install-option='--prefix=<PREFIX>' \
    -e git+https://github.com/PyTables/PyTables.git@v.2.3#egg=tables

## Bleeding Edge Versions

The latest, coolest, and possibly buggiest ;-) sources can be obtained from the new github repository:

https://github.com/PyTables/PyTables

A snapshot of the code in development is also available on the GitHub project page.

### Navigation

- index
- modules
- modules
- next
- previous
- PyTables 3.1.1 documentation »